@@ -1,6 +1,6 @@
 package App::GitGitr;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGitr::VERSION = '0.903';
+$App::GitGitr::VERSION = '0.904';
 # ABSTRACT: GitGitr command support. See L<gitgitr> for full documentation.
 
 use parent 'App::Cmd::Simple';
@@ -15,7 +15,7 @@ use Archive::Extract;
 use Carp;
 use File::Remove 'remove';
 use HTML::TreeBuilder::XPath;
-use LWP::Simple;
+use HTTP::Tiny;
 
 sub opt_spec {
   return (
@@ -38,13 +38,13 @@ sub execute {
     if $opt->{verbose};
 
   if ( -e $install_dir and ! $opt->{reinstall} ) {
-      if( $opt->{no_symlink} ) {
-          say "Most recent version ($version) already installed.";
-      }
-      else {
-        $self->_symlink( $opt , $version );
-        say "Most recent version ($version) already installed. /opt/git redirected to that version";
-      }
+    if( $opt->{no_symlink} ) {
+      say "Most recent version ($version) already installed.";
+    }
+    else {
+      $self->_symlink( $opt , $version );
+      say "Most recent version ($version) already installed. /opt/git redirected to that version";
+    }
   }
   else {
     chdir( '/tmp' );
@@ -73,13 +73,21 @@ sub execute {
 }
 
 sub _build_version {
-  my $content = get( 'http://git-scm.com/' );
+  my $response = HTTP::Tiny->new->get('http://git-scm.com/');
+  unless ( $response->{success} ) {
+    my $error = sprintf "Failed to fetch content from Git web page!\nSTATUS: %s REASON: %s" ,
+      $response->{status}, $response->{reason};
+    croak $error;
+  }
+
   my $tree = HTML::TreeBuilder::XPath->new;
-  $tree->parse_content( $content )
+  $tree->parse_content( $response->{content} )
     or croak "Failed to parse content from Git web page!";
+
   my $version = $tree->findvalue('/html/body//span[@class="version"]')
-    or croak "Can't parse version from Git web page! $content";
+    or croak "Can't parse version from Git web page!";
   $version =~ s/^\s*//; $version =~ s/\s*$//;
+
   return $version;
 }
 
@@ -166,7 +174,7 @@ App::GitGitr - GitGitr command support. See L<gitgitr> for full documentation.
 
 =head1 VERSION
 
-version 0.903
+version 0.904
 
 =head1 AUTHOR
 
@@ -174,7 +182,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2016 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
